.mode box

-- join everything together
-- allow caster_id to be null via left join
SELECT s.id    AS schedule_id,
       seg.id  AS segment_id,
       seg.n   AS title,
       c.id    AS caster_id,
       c.n     AS caster,
       s.jst   AS jst
  FROM schedule s
       JOIN      segment seg ON seg.id = s.segment_id
       LEFT JOIN caster  c   ON c.id   = s.caster_id;

-- [2023-08-19 Sat 16:49]
-- join even more data together
-- This may become the new schedule_joined.
SELECT s.id         AS id,
       seg.n        AS title,
       c.n          AS caster,
       s.video_id   AS video_id,
       s.view_count AS view_count,
       m.val        AS mscale,
       s.jst        AS jst
  FROM schedule s
       JOIN      segment seg ON seg.id = s.segment_id
       LEFT JOIN caster  c   ON c.id   = s.caster_id
       LEFT JOIN mscale  m   ON m.jst  = s.jst
 ORDER BY jst DESC
 LIMIT 48;

-- [2023-10-04 Wed 20:37] can we do a better job of guessing mscale?
-- just the hour
SELECT SUBSTR("2023-10-05T08:00:00+09:00", 12, 2);

-- just the date
SELECT SUBSTR("2023-10-05T08:00:00+09:00", 1, 10);

-- I have to turn jst into something I can group by.
-- This query breaks the day into 8 segements.
-- Eventually, I might turn this into a view and then join it with mscale again
--   so that I can have all hours of the day accounted for.
SELECT MAX(val) AS val,
       SUBSTR(jst, 1, 10) || " " ||
         CASE SUBSTR(jst, 12, 2)
         WHEN "00" THEN "00"
         WHEN "01" THEN "00"
         WHEN "02" THEN "00"
         WHEN "03" THEN "00"
         WHEN "04" THEN "00"
         WHEN "05" THEN "05"
         WHEN "06" THEN "05"
         WHEN "07" THEN "05"
         WHEN "08" THEN "08"
         WHEN "09" THEN "08"
         WHEN "10" THEN "08"
         WHEN "11" THEN "11"
         WHEN "12" THEN "11"
         WHEN "13" THEN "11"
         WHEN "14" THEN "14"
         WHEN "15" THEN "14"
         WHEN "16" THEN "14"
         WHEN "17" THEN "17"
         WHEN "18" THEN "17"
         WHEN "19" THEN "17"
         WHEN "20" THEN "20"
         WHEN "21" THEN "20"
         WHEN "22" THEN "20"
         WHEN "23" THEN "23"
         END
         AS gr,
       MIN(jst) AS jst
  FROM mscale
 WHERE jst <= "2023-10-06"
 GROUP BY gr
 ORDER BY jst DESC
 LIMIT 24;

-- curious about variation in starting times
SELECT substr(jst, 12, 5) AS t FROM schedule WHERE segment_id = &id GROUP BY t;

-- list of appearances by caster
SELECT seg.n      AS title,
       c.n        AS caster,
       s.video_id AS video_id,
       m.val      AS mscale,
       s.jst      AS jst
  FROM schedule s
       JOIN      segment seg ON seg.id = s.segment_id
       LEFT JOIN caster  c   ON c.id   = s.caster_id
       LEFT JOIN mscale  m   ON m.jst  = s.jst
 WHERE c.n = "&caster"
 ORDER BY jst DESC;

-- list of appearnces by segment
SELECT seg.n      AS title,
       c.n        AS caster,
       s.video_id AS video_id,
       m.val      AS mscale,
       s.jst      AS jst
  FROM schedule s
       JOIN      segment seg ON seg.id = s.segment_id
       LEFT JOIN caster  c   ON c.id   = s.caster_id
       LEFT JOIN mscale  m   ON m.jst  = s.jst
 WHERE seg.n = "&segment"
 ORDER BY jst DESC;

-- segment distribution for caster (including 0s)
SELECT seg.n AS t,
       COUNT(s.id) AS n -- it matters what we count; values from seg.* don't work
  FROM segment seg
       LEFT JOIN schedule s
           ON s.segment_id = seg.id
           AND s.caster_id = (SELECT id FROM caster WHERE n = "&caster")
                   -- The final AND on the LEFT JOIN was key.
 GROUP BY t
HAVING t != "_"
 ORDER BY n DESC;

-- segment distribution for caster
SELECT seg.n AS title,
       COUNT(seg.title) AS n
  FROM schedule s
       JOIN segment seg ON seg.id = s.segment_id
       JOIN caster  c   ON c.id   = s.caster_id
 WHERE c.n = "&caster"
 GROUP BY title
 ORDER BY n DESC;

-- segment distribution for caster using prejoined view
SELECT title,
       COUNT(title) AS appearances
  FROM schedule_joined
 WHERE caster = "&caster"
 GROUP BY title
 ORDER BY appearances DESC;

-- caster distribution for segment
SELECT caster,
       COUNT(*) AS appearances
  FROM schedule_joined
 WHERE title = "&title"
 GROUP BY caster
 ORDER BY appearances DESC;

-- appearances by caster
SELECT caster,
       COUNT(caster) AS appearances
  FROM schedule_joined
 WHERE caster IS NOT NULL
 GROUP BY caster
 ORDER BY appearances DESC, caster ASC;

-- appearances by caster for a date range
SELECT caster,
       COUNT(caster) AS appearances
  FROM schedule_joined
 WHERE caster IS NOT NULL
   AND jst BETWEEN '&a' AND '&b' -- try 2023-08-01 and 2023-09-01 as values
 GROUP BY caster
 ORDER BY appearances DESC, caster ASC;

-- list of all known casters
SELECT * FROM caster;

-- list of all segments
SELECT * FROM segment;

-- list the historical schedule using schedule_joined
SELECT * FROM schedule_joined ORDER BY jst;

-- list cancellations and join
SELECT seg.n AS title,
       c.n   AS caster,
       m.val AS mscale,
       s.jst AS jst
  FROM cancellation s
       JOIN      segment seg ON seg.id = s.segment_id
       LEFT JOIN caster  c   ON c.id   = s.caster_id
       LEFT JOIN mscale  m   ON s.jst  = m.jst
 ORDER BY jst;

-- caster distribution by day of week
-- 0 = Sunday, 1 = Monday, ...
SELECT STRFTIME("%w", jst) AS dow,
       COUNT(caster) AS n
  FROM schedule_joined
 WHERE caster = "&caster"
 GROUP BY dow;

-- caster distribution by day of week (spelled out)
-- https://stackoverflow.com/a/4321225
SELECT CASE CAST(STRFTIME("%w", jst) AS INTEGER)
       WHEN 0 THEN 'Sunday'
       WHEN 1 THEN 'Monday'
       WHEN 2 THEN 'Tuesday'
       WHEN 3 THEN 'Wednesday'
       WHEN 4 THEN 'Thursday'
       WHEN 5 THEN 'Friday'
       ELSE 'Saturday'
       END AS dow,
       COUNT(caster) AS n
  FROM schedule_joined
 WHERE caster = "&caster"
 GROUP BY dow
 ORDER BY STRFTIME("%w", jst);

-- Find days where a segment was scheduled more than once.
SELECT DATE(jst) AS dt,
       segment_id,
       COUNT(segment_id) AS c
  FROM schedule
 WHERE segment_id <= 6
 GROUP BY dt, segment_id
HAVING c > 1
 ORDER BY dt DESC;

-- Caster's Last Appearance (ignoring au PAY)
SELECT c.n AS name,
       JULIANDAY(DATETIME('now', '+09:00')) - JULIANDAY(MAX(s.jst)) AS days_since,
       MAX(s.jst) AS last_appearance
  FROM schedule s
       JOIN caster c ON c.id = s.caster_id
 WHERE s.jst < REPLACE(DATETIME('now', '+09:00'), ' ', 'T')
   AND s.segment_id != 8
 GROUP BY c.n
 ORDER BY last_appearance DESC;

-- Max days between caster appearances for all casters
-- https://boards.4chan.org/jp/thread/46572416#p46585501
SELECT name, MAX(diff) as days, prev, jst
  FROM (SELECT c.n AS name,
               JULIANDAY(s.jst) - LAG(JULIANDAY(s.jst), 1, 0) OVER (ORDER BY s.caster_id, s.jst) AS diff,
               s.jst AS jst,
               LAG(s.jst, 1, 0) OVER (ORDER BY s.caster_id, s.jst) AS prev
          FROM schedule s
               JOIN caster c ON c.id = s.caster_id
         WHERE s.segment_id != 8
         ORDER BY s.caster_id, s.jst)
 WHERE prev != 0
 GROUP BY name
 ORDER BY days DESC;

-- Max days between caster appearances
SELECT name, MAX(diff) AS days, prev, jst FROM (
    SELECT c.n AS name,
           JULIANDAY(s.jst) - LAG(JULIANDAY(s.jst), 1, 0) OVER (ORDER BY s.jst) AS diff,
           s.jst AS jst,
           LAG(s.jst, 1, 0) OVER (ORDER BY s.jst) AS prev
      FROM schedule s
           JOIN caster c ON c.id = s.caster_id
     WHERE c.n = "&caster"
       AND s.segment_id != 8
     ORDER BY s.jst) gaps
 WHERE prev != 0;

-- Top 3 days between caster appearances
SELECT name, diff AS days, prev, jst FROM (
    SELECT c.n AS name,
           JULIANDAY(s.jst) - LAG(JULIANDAY(s.jst), 1, 0) OVER (ORDER BY s.jst) AS diff,
           s.jst AS jst,
           LAG(s.jst, 1, 0) OVER (ORDER BY s.jst) AS prev
      FROM schedule s
           JOIN caster c ON c.id = s.caster_id
     WHERE c.n = "&caster"
       AND s.segment_id != 8
     ORDER BY s.jst) gaps
 WHERE prev != 0
 ORDER BY gaps.diff DESC
 LIMIT 3;

-- Days between caster appearances
SELECT c.n   AS name,
       JULIANDAY(s.jst) - LAG(JULIANDAY(s.jst), 1, 0) OVER (ORDER BY s.jst) AS diff,
       s.jst AS jst,
       LAG(s.jst, 1, 0) OVER (ORDER BY s.jst) AS prev
  FROM schedule s
       JOIN caster c ON c.id = s.caster_id
 WHERE c.n = "&caster"
   AND s.segment_id != 8
 ORDER BY s.jst;

-- Views by caster (for debugging)
SELECT c.n AS name,
       s.video_id,
       s.view_count,
       s.jst
  FROM schedule s
       JOIN caster c ON c.id = s.caster_id
 WHERE view_count IS NOT NULL
   AND c.n = "&caster"
 ORDER BY view_count DESC;

-- Average views for casters
SELECT c.n AS name,
       AVG(s.view_count) AS avg_views,
       COUNT(s.view_count) AS appearances
  FROM schedule s
       JOIN caster c ON c.id = s.caster_id
 WHERE view_count IS NOT NULL
   AND view_count != 0
 GROUP BY c.n
 ORDER BY avg_views DESC;

-- Views by segment (for debugging)
SELECT seg.n AS name,
       s.video_id,
       s.view_count,
       s.jst
  FROM schedule s
       JOIN segment seg ON seg.id = s.segment_id
 WHERE view_count IS NOT NULL
   AND seg.n = "&segment"
 ORDER BY view_count DESC;

-- Average views for segments
SELECT seg.n AS name,
       AVG(s.view_count) AS avg_views,
       COUNT(s.view_count) AS appearances
  FROM schedule s
       JOIN segment seg ON seg.id = s.segment_id
 WHERE view_count IS NOT NULL
   AND view_count != 0
 GROUP BY seg.n
 ORDER BY avg_views DESC;

-- Appearances by caster, month, segment
SELECT c.n,
       STRFTIME("%Y%m", jst) AS yyyymm,
       seg.n AS segment,
       COUNT(s.caster_id) AS appearances
  FROM schedule s
       JOIN caster c ON c.id = s.caster_id
       JOIN segment seg ON seg.id = s.segment_id
 WHERE c.n = "&caster"
   AND seg.n = "&segment"
 GROUP BY c.n, yyyymm, title;

-- MANUAL FIXES

-- copy matsu's cancelled coffee time to cancellation table
INSERT INTO cancellation SELECT id, caster_id, segment_id, jst FROM schedule WHERE id = 152;
-- update row 152 so that uozumi hosts that coffee time slot instead
UPDATE schedule SET caster_id = 4 WHERE id = 152;

-- matsu cancelled again
INSERT INTO cancellation SELECT id, caster_id, segment_id, jst FROM schedule WHERE id = 169;
UPDATE schedule SET caster_id = 4 WHERE id = 169;

-- matsu cancelled again [2023-08-10 Wed 14:00]
INSERT INTO cancellation SELECT id, caster_id, segment_id, jst FROM schedule WHERE id = 178;
UPDATE schedule SET caster_id = 8 WHERE id = 178;

-- komaki cancelled moon [2023-08-13 Sun 20:00]
INSERT INTO cancellation SELECT id, caster_id, segment_id, jst FROM schedule WHERE id = 204;
UPDATE schedule SET caster_id = 11 WHERE id = 204;

-- mizuki cancelled evening [2023-08-18 Fri 17:00]
INSERT INTO cancellation SELECT id, caster_id, segment_id, jst FROM schedule WHERE id = 243;
UPDATE schedule SET caster_id = NULL WHERE id = 243;

-- first manually added schedule.video_id
UPDATE schedule SET video_id = "YzJ-v2UswOw" WHERE id = 252;
UPDATE schedule SET video_id = "pX0ZEKzxnb4" WHERE id = 251;
UPDATE schedule SET video_id = "VW2bKfs-uC8" WHERE id = 254;

-- [2023-08-22 Tue 23:03] fill in a missing mscale entry
INSERT INTO mscale (val, jst)
VALUES (1, "2023-08-23T14:00:00+09:00");

-- [2023-08-23 Wed 12:19] fix video_id; the wn api gave me stale data
UPDATE schedule SET video_id = "RNLPoVy_s6c" WHERE jst = "2023-08-22T20:00:00+09:00";
UPDATE schedule SET video_id = "72Axhbwul5U" WHERE jst = "2023-08-22T23:00:00+09:00";

-- 2023-08-26T05:00:00+09:00 the video_id needs to be replaced
-- It video_ids API call was stale very late into the show.
UPDATE schedule SET video_id = "kqOnuwQC7sk" WHERE jst = "2023-08-26T05:00:00+09:00";

-- ohshima cancelled coffee time [2023-08-30 Wed 11:00]
INSERT INTO cancellation SELECT id, caster_id, segment_id, jst FROM schedule WHERE id = 337;
UPDATE schedule SET caster_id = 5 WHERE id = 337;

-- credit komaki2018 for schedule.id = 357
UPDATE schedule SET caster_id = 8 WHERE id = 357;

-- au PAY Market
INSERT INTO segment (id, n, title) VALUES (8, "au PAY", "ライブTV − au PAY マーケット");
INSERT INTO schedule (caster_id, segment_id, jst, video_id) VALUES (4, 8, "2023-08-31T18:00:00+09:00", "10213");
-- au PAY 10211 found via @pta's curiosity
INSERT INTO schedule (segment_id, caster_id, video_id, jst)
VALUES (8, 6, "10211", "2023-07-27T18:00:00+09:00");
-- au PAY 10227 Adding Rinon's show manually
INSERT INTO schedule (segment_id, caster_id, video_id, jst)
VALUES (8, 10, "10227", "2023-09-04T19:00:00+09:00");
-- fix video_id from previous; my other script overwrote it by accident
UPDATE schedule SET video_id = "10227" WHERE id = 403;
-- au PAY 9970 for Nana found via gallery-dl of @livetv_aupaymkt
INSERT INTO schedule (segment_id, caster_id, video_id, jst)
VALUES (8, 1, "9970", "2023-05-12T19:00:00+09:00");

-- [2023-09-20 Wed 20:04] Fill in missing data due to wn.db being locked.
INSERT INTO mscale (val, jst)
VALUES (1, "2023-09-21T00:00:00+09:00"),
       (1, "2023-09-21T01:00:00+09:00"),
       (1, "2023-09-21T02:00:00+09:00"),
       (1, "2023-09-21T03:00:00+09:00"),
       (1, "2023-09-21T04:00:00+09:00"),
       (1, "2023-09-21T05:00:00+09:00"),
       (1, "2023-09-21T06:00:00+09:00"),
       (1, "2023-09-21T07:00:00+09:00"),
       (1, "2023-09-21T08:00:00+09:00"),
       (1, "2023-09-21T09:00:00+09:00"),
       (1, "2023-09-21T10:00:00+09:00"),
       (1, "2023-09-21T11:00:00+09:00");
-- [2023-09-20 Wed 20:17] missing video_ids
UPDATE schedule SET video_id = "T97iFaGvS4Y" WHERE jst = "2023-09-21T00:00:00+09:00";
UPDATE schedule SET video_id = "rn83ST3W4TU" WHERE jst = "2023-09-21T05:00:00+09:00";
UPDATE schedule SET video_id = "UqKpV4z5Xwk" WHERE jst = "2023-09-21T08:00:00+09:00";

-- [2023-09-21 Thu 19:28] Add video_id for kobayashi+ogawa+yui au PAY
UPDATE schedule SET video_id = "10238" WHERE id IN (533, 534, 535);
UPDATE schedule SET video_id = "10237" WHERE id = 532;
UPDATE schedule SET video_id = "10235" WHERE id IN (530, 531);

-- [2023-10-04 Wed 23:20] Add upcoming au PAY shows
INSERT INTO schedule (caster_id, segment_id, jst)
VALUES (11, 8, "2023-10-07T19:00:00+09:00"),
       ( 9, 8, "2023-10-13T19:00:00+09:00"),
       ( 2, 8, "2023-10-20T19:00:00+09:00"),
       ( 5, 8, "2023-10-23T19:00:00+09:00"),
       ( 3, 8, "2023-10-30T19:00:00+09:00");

-- [2023-10-06 Fri 20:11] Add video_id for Saya's au PAY show
UPDATE schedule SET video_id = "10312" WHERE jst = "2023-10-07T19:00:00+09:00";

-- [2023-10-12 Thu 03:17] Add video_id for Riena's au PAY show
UPDATE schedule SET video_id = "10317" WHERE jst = "2023-10-13T19:00:00+09:00";

-- [2023-10-19 Thu 03:16] Add video_id for Airin's au PAY show
UPDATE schedule SET video_id = "10322" WHERE jst = "2023-10-20T19:00:00+09:00";

-- [2023-10-22 Sun 02:31] Add video_id for Senna's au PAY show
UPDATE schedule SET video_id = "10325" WHERE jst = "2023-10-23T19:00:00+09:00";

-- [2023-10-27 Fri 17:48] Add video_id for Mizuki's au PAY show
UPDATE schedule SET video_id = "10329" WHERE jst = "2023-10-30T19:00:00+09:00";

-- [2023-11-06 Mon 02:06] Insert schedule row for Saya's au PAY show
INSERT INTO schedule (caster_id, segment_id, video_id, jst)
VALUES (11, 8, "10401", "2023-11-06T19:00:00+09:00");

-- [2023-11-06 Mon 02:24] Insert schedule row for Rinon's au PAY show
INSERT INTO schedule (caster_id, segment_id, video_id, jst)
VALUES (10, 8, "10408", "2023-11-08T19:00:00+09:00");

-- [2023-11-06 Mon 13:44] Fix missing video_id due to daylight savings bug
UPDATE schedule SET video_id = "dD8KgE9Gko8" WHERE jst = "2023-11-05T17:00:00+09:00";

-- [2023-11-11 Sat 16:15] Add upcoming au PAY shows
INSERT INTO schedule (caster_id, segment_id, jst)
VALUES ( 8, 8, "2023-11-17T19:00:00+09:00"),
       ( 4, 8, "2023-11-23T19:00:00+09:00"),
       ( 9, 8, "2023-11-27T19:00:00+09:00"),
       ( 6, 8, "2023-11-29T17:00:00+09:00");

-- [2023-11-17 Fri 01:23] Add video_id for Yui's au PAY show
UPDATE schedule SET video_id = "10419" WHERE jst = "2023-11-17T19:00:00+09:00";

-- [2023-11-17 Fri 01:23] Add video_id for Riena's au PAY show
UPDATE schedule SET video_id = "10430" WHERE jst = "2023-11-27T19:00:00+09:00";

-- [2023-11-17 Fri 01:23] Add video_id for Mayu and Ayaka's au PAY shows
UPDATE schedule SET video_id = "10428" WHERE jst = "2023-11-23T19:00:00+09:00";
UPDATE schedule SET video_id = "10433" WHERE jst = "2023-11-29T17:00:00+09:00";

-- [2023-11-17 Fri 03:43] fix a stale video_id
UPDATE schedule SET video_id = "pRQl2nS85EA" WHERE jst = "2023-11-17T20:00:00+09:00";

-- [2023-11-29 Wed 02:19] upgraded Julia without reinstantiating WeatherNews.jl
UPDATE schedule SET video_id = "wTawHroGUmY" WHERE jst = "2023-11-29T17:00:00+09:00";
UPDATE schedule SET video_id = "S2AzgUsJ3Jg" WHERE jst = "2023-11-29T14:00:00+09:00";
UPDATE schedule SET video_id = "t5qh9yuh7Yk" WHERE jst = "2023-11-29T11:00:00+09:00";

-- [2023-12-05 Tue 22:25] Add upcoming au PAY show for Ayaka
INSERT INTO schedule (caster_id, segment_id, jst)
VALUES ( 6, 8, "2023-12-08T19:00:00+09:00");
UPDATE schedule SET video_id = "10485" WHERE jst = "2023-12-08T19:00:00+09:00";

-- [2023-12-11 Mon 17:34] Add upcoming au PAY show for Senna
INSERT INTO schedule (caster_id, segment_id, video_id, jst)
VALUES ( 5, 8, "10502", "2023-12-21T19:00:00+09:00");

-- [2023-12-21 Thu 15:45] Add year end au PAY shows
INSERT INTO schedule (caster_id, segment_id, video_id, jst)
VALUES ( 9, 8, "10507", "2023-12-28T17:00:01+09:00"),
       ( 8, 8, "10508", "2023-12-29T17:00:01+09:00"),
       (13, 8, "10508", "2023-12-29T17:00:02+09:00"),
       (12, 8, "10508", "2023-12-29T17:00:03+09:00");

-- [2024-01-03 Wed 08:33] au PAY 2024-01
INSERT INTO schedule (caster_id, segment_id, video_id, jst)
VALUES ( 2, 8, "10563", "2024-01-05T19:00:00+09:00"),
       ( 9, 8, "10568", "2024-01-10T19:00:00+09:00"),
       (13, 8,    NULL, "2024-01-13T19:00:00+09:00"),
       ( 6, 8,    NULL, "2024-01-18T19:00:00+09:00"),
       ( 8, 8,    NULL, "2024-01-23T19:00:00+09:00"),
       ( 3, 8,    NULL, "2024-01-29T19:00:00+09:00");

-- [2024-01-10 Wed 03:38] Add video_ids for Momoka and Ayaka's upcoming au PAY streams
UPDATE schedule SET video_id = "10576" WHERE jst = "2024-01-13T19:00:00+09:00";
UPDATE schedule SET video_id = "10587" WHERE jst = "2024-01-18T19:00:00+09:00";

-- [2024-01-20 Sat 02:39] Add video_ids for Yui and Mizuki's upcoming au PAY streams
UPDATE schedule SET video_id = "10593" WHERE jst = "2024-01-23T19:00:00+09:00";
UPDATE schedule SET video_id = "10601" WHERE jst = "2024-01-29T19:00:00+09:00";

-- [2024-01-30 Tue 23:42] au PAY 2024-02
INSERT INTO schedule (caster_id, segment_id, video_id, jst)
VALUES (11, 8, "10646", "2024-02-05T19:00:00+09:00"),
       ( 5, 8, "10650", "2024-02-09T19:00:00+09:00"),
       (13, 8,    NULL, "2024-02-13T19:00:00+09:00"),
       (10, 8,    NULL, "2024-02-19T19:00:00+09:00"),
       ( 3, 8,    NULL, "2024-02-27T19:00:00+09:00"),
       ( 8, 8,    NULL, "2024-02-29T19:00:00+09:00");

-- [2024-02-04 Sun 18:17] Fix stale video_id
UPDATE schedule SET video_id = "rHH_-v0ukIg" WHERE id = 1674;

-- [2024-02-05 Mon 13:38] Fix stale video_id
UPDATE schedule SET video_id = "q7JNH0Zio6E" WHERE id IN (1678, 1679);

-- [2024-02-07 Wed 14:27] add more au PAY video_ids
UPDATE schedule SET video_id = "10652" WHERE jst = "2024-02-13T19:00:00+09:00";
-- where are the video_ids for ohshima and tokita?
UPDATE schedule SET video_id = "10666" WHERE jst = "2024-02-29T19:00:00+09:00";
-- [2024-02-14 Wed 15:11] Found ohshima
UPDATE schedule SET video_id = "10657" WHERE jst = "2024-02-19T19:00:00+09:00";
-- [2024-02-24 Sat 16:37] Found tokita
UPDATE schedule SET video_id = "10664" WHERE jst = "2024-02-27T19:00:00+09:00";


-- [2024-02-20 Tue 03:32] fix stale video_ids
UPDATE schedule SET video_id = "8BwRkzT9RSY" WHERE jst = "2024-02-20T23:00:00+09:00"; -- late night
UPDATE schedule SET video_id = "T150X3mrE6w" WHERE jst = "2024-02-20T20:00:00+09:00"; -- hiyama2018
UPDATE schedule SET video_id = "oCJlWJxwecg" WHERE jst = "2024-02-20T17:00:00+09:00"; -- ailin
UPDATE schedule SET video_id = "JvvdsaFxCRs" WHERE jst = "2024-02-20T14:00:00+09:00"; -- kawabata
UPDATE schedule SET video_id = "0pN4YMeu53M" WHERE jst = "2024-02-20T11:00:00+09:00"; -- matsu

-- [2024-03-06 Wed 05:21] Add upcoming au PAY shows for 2024-03
INSERT INTO schedule (caster_id, segment_id, video_id, jst)
VALUES ( 4, 8, "10710", "2024-03-11T19:00:00+09:00"),
       ( 6, 8, "10716", "2024-03-19T19:00:00+09:00");

-- [2024-03-11 Mon 15:40] Add more au PAY shows for 2024-03
INSERT INTO schedule (caster_id, segment_id, video_id, jst)
VALUES ( 2, 8, "10719", "2024-03-23T12:30:00+09:00"),
       ( 9, 8, "10719", "2024-03-23T12:30:01+09:00");

INSERT INTO schedule (caster_id, segment_id, video_id, jst)
VALUES ( 8, 8, "10723", "2024-03-29T07:00:00+09:00"),
       (13, 8, "10723", "2024-03-29T07:00:01+09:00"),
       ( 8, 8, "10724", "2024-03-29T11:00:01+09:00"),
       (13, 8, "10724", "2024-03-29T11:00:02+09:00"),
       ( 8, 8, "10725", "2024-03-29T14:30:00+09:00"),
       (13, 8, "10725", "2024-03-29T14:30:01+09:00"),
       ( 8, 8, "10726", "2024-03-29T18:00:00+09:00"),
       (13, 8, "10726", "2024-03-29T18:00:01+09:00");

-- [2024-03-29 Fri 13:39] Add upcoming au PAY shows for 2024-04
INSERT INTO schedule (caster_id, segment_id, video_id, jst)
VALUES (12, 8, "10747", "2024-04-02T19:00:00+09:00"),
       ( 4, 8, "10749", "2024-04-09T19:00:00+09:00"),
       ( 5, 8, "",      "2024-04-15T19:00:00+09:00"),
       (10, 8, "",      "2024-04-19T19:00:00+09:00");

-- [2024-04-11 Thu 09:24] Add video_id for Senna's au PAY
UPDATE schedule SET video_id = "10755" WHERE jst = "2024-04-15T19:00:00+09:00";

-- [2024-04-15 Mon 23:33] Add missing data after home server crashed
-- video_id for kawabata's afternoon show
UPDATE schedule SET video_id = "h5YwZ5ZV2ns" WHERE jst = "2024-04-16T14:00:00+09:00";

-- [2024-04-16 Tue 06:08] More au PAY ids
UPDATE schedule SET video_id = "10761" WHERE jst = "2024-04-19T19:00:00+09:00";

-- au PAY glamping with yui and momoka
INSERT INTO schedule (caster_id, segment_id, video_id, jst)
VALUES ( 8, 8, "10765", "2024-04-24T19:00:00+09:00"),
       (13, 8, "10765", "2024-04-24T19:00:01+09:00"); 

-- au PAY rebroadcast of saya yui glamping
INSERT INTO schedule (caster_id, segment_id, video_id, jst)
VALUES (11, 8, "10796", "2024-04-23T19:00:00+09:00"),
       ( 8, 8, "10796", "2024-04-23T19:00:01+09:00");

-- [2024-04-28 Sun 02:16] Add upcoming au PAY shows for 2024-05
INSERT INTO schedule (caster_id, segment_id, video_id, jst)
VALUES ( 2, 8, "10799", "2024-05-01T19:00:00+09:00"),
       ( 9, 8, "10805", "2024-05-08T19:00:00+09:00"),
       ( 6, 8, "10812", "2024-05-13T19:00:00+09:00"),
       ( 3, 8, "10822", "2024-05-21T19:00:00+09:00"),
       (12, 8, "10827", "2024-05-24T19:00:00+09:00"),
       ( 5, 8, "10834", "2024-05-31T19:00:00+09:00");
