package WNDB;

sub schedule_default {
  my $sql = shift;
  my $query = "
    SELECT seg.n        AS title,
           c.n          AS caster,
           s.video_id   AS video_id,
           m.val        AS mscale,
           s.view_count AS view_count,
           s.jst        AS jst
      FROM schedule s
           JOIN      segment seg ON seg.id = s.segment_id
           LEFT JOIN caster  c   ON c.id   = s.caster_id
           LEFT JOIN mscale  m   ON m.jst  = s.jst
     ORDER BY jst DESC;";
  return $sql->($query);
}

sub schedule_by_caster {
  my $sql = shift;
  my $caster = shift;
  my $query = "
    -- list of appearances by caster
    SELECT seg.n        AS title,
           c.n          AS caster,
           s.video_id   AS video_id,
           m.val        AS mscale,
           s.view_count AS view_count,
           s.jst        AS jst
      FROM schedule s
           JOIN      segment seg ON seg.id = s.segment_id
           LEFT JOIN caster  c   ON c.id   = s.caster_id
           LEFT JOIN mscale  m   ON m.jst  = s.jst
     WHERE c.n = ?
     ORDER BY jst DESC;";
  return $sql->($query, $caster);
}

sub schedule_by_segment {
  my $sql = shift;
  my $segment = shift;
  my $query = "
    -- list of appearances by caster
    SELECT seg.n        AS title,
           c.n          AS caster,
           s.video_id   AS video_id,
           m.val        AS mscale,
           s.view_count AS view_count,
           s.jst        AS jst
      FROM schedule s
           JOIN      segment seg ON seg.id = s.segment_id
           LEFT JOIN caster  c   ON c.id   = s.caster_id
           LEFT JOIN mscale  m   ON m.jst  = s.jst
     WHERE seg.n = ?
     ORDER BY jst DESC;";
  return $sql->($query, $segment);
}

sub segment_distribution_for_caster {
  my $sql = shift;
  my $caster = shift;
  my $query = "
    SELECT title as segment,
           COUNT(*) AS appearances
      FROM schedule_joined
     WHERE caster = ?
     GROUP BY title
     ORDER BY appearances DESC";
  return $sql->($query, $caster)
}

sub caster_distribution_for_segment {
  my $sql = shift;
  my $segment = shift;
  my $query = "
    SELECT caster,
           COUNT(*) AS appearances
      FROM schedule_joined
     WHERE title = ?
     GROUP BY caster
     ORDER BY appearances DESC";
  return $sql->($query, $segment);
}

sub appearances {
  my $sql = shift;
  my $query = "
    SELECT caster,
           COUNT(caster) AS appearances
      FROM schedule_joined
     WHERE caster IS NOT NULL
     GROUP BY caster
     ORDER BY appearances DESC, caster ASC;
  ";
  return $sql->($query);
}

sub appearances_between {
  my $sql = shift;
  my $begin = shift;
  my $end = shift;
  my $query = "
    SELECT caster,
           COUNT(caster) AS appearances
      FROM schedule_joined
     WHERE caster IS NOT NULL
       AND jst BETWEEN ? AND ?
     GROUP BY caster
     ORDER BY appearances DESC, caster ASC;
  ";
  return $sql->($query, $begin, $end);
}

sub min_max_jst {
  my $sql = shift;
  my $query = "
    SELECT MIN(jst) as min_jst,
           MAX(jst) as max_jst
      FROM schedule";
  return $sql->($query);
}

sub casters {
  my $sql = shift;
  my $query = "SELECT * FROM caster ORDER BY n";
  return $sql->($query);
}

sub segments {
  my $sql= shift;
  my $query = "SELECT * FROM segment ORDER BY id";
  return $sql->($query);
}

1;
