#!/usr/bin/env perl
use strict;
use warnings;
use local::lib;

use DBI;
use DBD::SQLite;
use CGI::Tiny;
use Time::Piece;

require('../WNDB.pm');
require('../Utils.pm');

our %config = (
  base => "/",
  database => "dbi:SQLite:dbname=wn.db"
);
if (-e "../config.pl") {
  %config = (%config, do "../config.pl");
}
my $dbh = DBI->connect($config{database});
my ($sql, $do) = sql_fn($dbh);

cgi {
  my $cgi = $_;
  my ($dates) = WNDB::min_max_jst($sql);
  my $min_jst = $dates->{min_jst};
  my $max_jst = $dates->{max_jst};
  $min_jst =~ s/T.*$//;
  $max_jst =~ s/T.*$//;
  my $max_tp = Time::Piece->strptime($max_jst, "%Y-%m-%d");
  # Add one day to the max so none of the current day
  # data is missed.
  my $max_plus = $max_tp + (60 * 60 * 24);
  $max_jst = $max_plus->strftime("%Y-%m-%d");
  my $begin = $_->query_param('begin') // $min_jst;
  my $end = $_->query_param('end')  // $max_jst;
  my @r = WNDB::appearances_between($sql, $begin, $end);
  my $dist = dist_to_arrayrefs(\@r);
  my $html = page('ranking', {
    base => $config{base},
    rows => $dist->{rows},
    total => $dist->{total},
    min_jst => $min_jst,
    max_jst => $max_jst,
    begin => $begin,
    end => $end
  });
  $cgi->render(html => $html);
};
