#!/usr/bin/env perl
use strict;
use warnings;
use local::lib;

use DBI;
use DBD::SQLite;
use CGI::Tiny;

require('../WNDB.pm');
require('../Utils.pm');

our %config = (
  base => "/",
  database => "dbi:SQLite:dbname=wn.db"
);
if (-e "../config.pl") {
  %config = (%config, do "../config.pl");
}
my $dbh = DBI->connect($config{database});
my ($sql, $do) = sql_fn($dbh);

cgi {
  my $cgi = $_;
  my $n = $cgi->query_param('n');
  if ($n) {
    my @r = WNDB::schedule_by_segment($sql, $n);
    mark_live(\@r);
    my @dist = WNDB::caster_distribution_for_segment($sql, $n);
    my $d = dist_to_arrayrefs(\@dist);
    my $html = page('schedule_dist', { 
      base    => $config{base}, 
      n       => $n, 
      headers => $d->{headers}, 
      dist    => $d->{rows},
      total   => $d->{total},
      r       => \@r 
    });
    $cgi->render(html => $html);
  } else {
    my @segments = WNDB::segments($sql);
    my $html = page('segment_list', { base => $config{base}, segments => \@segments });
    $cgi->render(html => $html);
  }
};
